checks to see if a .gitignore needs to be create or edited based on the template file
Source:R/gitignore_init.R
gitignore_init.Rdchecks to see if a .gitignore needs to be create or edited based on the template file
Usage
gitignore_init(
template = system.file("extdata/gitignore_template", package = "cctu")
)