Function to write a text into xml format in the correct directory, and edit TableofTables
Source:R/write_text.R
write_text.RdFunction to write a text into xml format in the correct directory, and edit TableofTables
Arguments
- x
the character string (or vector of strings) to be saved in xml format. A vector is concatenated into a single text block.
- number
the number used as a suffix in the output filename, and to link to the meta_table. Default is to use the value in the cctu_env package environment that is set within
attach_pop.- clean_up
logical to invoke the
clean_upfunction at the end. Defaults toTRUE.- directory
where to save the text within path or current working directory. Defaults to
file.path(cctu_opt("output"), "Core").- verbose
logical to print information on changes to the global environment or external files. Defaults to
options()$verbose.
Value
writes an xml version of the input data to file text_number.xml . Edits the TableofTables object with the calling programe. No return object.